@@ -2,9 +2,7 @@ use ark_crypto_primitives::Error;
 use ark_ff::{fields::PrimeField, BigInteger};
 use ark_r1cs_std::{fields::fp::FpVar, prelude::*, uint8::UInt8};
 use ark_relations::r1cs::SynthesisError;
-#[cfg(feature = "etherhash")]
 use ethabi::{encode, Token};
-#[cfg(feature = "etherhash")]
 use tiny_keccak::{Hasher, Keccak};
 
 pub mod common;
@@ -147,84 +145,60 @@ pub fn get_rounds_mimc_220<F: PrimeField>() -> Vec<F> {
 	parse_vec(crate::mimc::CONSTANTS.to_vec())
 }
 
-#[cfg(feature = "etherhash")]
-pub fn check_inputs_arbitrary_ethabi(
-	recipient: &Token,
-	ext_amount: &Token,
-	relayer: &Token,
-	fee: &Token,
-	encrypted_output1: &Token,
-	encrypted_output2: &Token,
-) {
-	match recipient {
-		Token::Address(_address) => {}
-		_ => {
-			panic!("recipient address is not valid");
+#[derive(Debug)]
+pub struct ExtData {
+	pub recipient_bytes: Vec<u8>,
+	pub relayer_bytes: Vec<u8>,
+	pub ext_amount_bytes: Vec<u8>,
+	pub fee_bytes: Vec<u8>,
+	pub encrypted_output1_bytes: Vec<u8>,
+	pub encrypted_output2_bytes: Vec<u8>,
+}
+
+impl ExtData {
+	pub fn new(
+		recipient_bytes: Vec<u8>,
+		relayer_bytes: Vec<u8>,
+		ext_amount_bytes: Vec<u8>,
+		fee_bytes: Vec<u8>,
+		encrypted_output1_bytes: Vec<u8>,
+		encrypted_output2_bytes: Vec<u8>,
+	) -> Self {
+		Self {
+			recipient_bytes,
+			relayer_bytes,
+			ext_amount_bytes,
+			fee_bytes,
+			encrypted_output1_bytes,
+			encrypted_output2_bytes,
 		}
 	}
-	match ext_amount {
-		Token::Int(_u256) => {}
-		_ => {
-			panic!("the ext_amount is not valid");
-		}
+
+	// TODO: fix types of tokens
+	fn into_abi(&self) -> Token {
+		let recipient = Token::Bytes(self.recipient_bytes.clone());
+		let ext_amount = Token::Bytes(self.ext_amount_bytes.clone());
+		let relayer = Token::Bytes(self.relayer_bytes.clone());
+		let fee = Token::Bytes(self.fee_bytes.clone());
+		let encrypted_output1 = Token::Bytes(self.encrypted_output1_bytes.clone());
+		let encrypted_output2 = Token::Bytes(self.encrypted_output2_bytes.clone());
+		Token::Tuple(vec![
+			recipient,
+			relayer,
+			ext_amount,
+			fee,
+			encrypted_output1,
+			encrypted_output2,
+		])
 	}
-	match relayer {
-		Token::Address(_address) => {}
-		_ => {
-			panic!("relayer address is not valid");
-		}
-	}
-	match fee {
-		Token::Uint(_u256) => {}
-		_ => {
-			panic!("fee is not valid");
-		}
-	}
-	match encrypted_output1 {
-		Token::Bytes(_bytes) => {}
-		_ => {
-			panic!("encrypted_output1 is not valid");
-		}
-	}
-	match encrypted_output2 {
-		Token::Bytes(_bytes) => {}
-		_ => {
-			panic!("encrypted_output2 is not valid");
-		}
+
+	pub fn encode_abi(&self) -> Vec<u8> {
+		let token = self.into_abi();
+		let encoded_input = encode(&[token]);
+		encoded_input
 	}
 }
 
-#[cfg(feature = "etherhash")]
-pub fn vanchor_arbitrary_hash(
-	recipient: Token,
-	ext_amount: Token,
-	relayer: Token,
-	fee: Token,
-	encrypted_output1: Token,
-	encrypted_output2: Token,
-) -> Vec<u8> {
-	check_inputs_arbitrary_ethabi(
-		&recipient,
-		&ext_amount,
-		&relayer,
-		&fee,
-		&encrypted_output1,
-		&encrypted_output2,
-	);
-	let tuple = [Token::Tuple(vec![
-		recipient,
-		ext_amount,
-		relayer,
-		fee,
-		encrypted_output1,
-		encrypted_output2,
-	])];
-	let encoded_input = encode(&tuple);
-	let bytes: &[u8] = &encoded_input;
-	keccak_256(bytes)
-}
-
-#[cfg(feature = "etherhash")]
 pub fn keccak_256(input: &[u8]) -> Vec<u8> {
 	let mut hasher = Keccak::v256();
 	hasher.update(input);
